Xqt has submitted this change and it was merged.

Change subject: A little description about not showing characters when you type 
passwords, which always confuses people
......................................................................


A little description about not showing characters when you type passwords, 
which always confuses people

implemented partially from [1]

[1] https://gerrit.wikimedia.org/r/#/c/79730/4/pywikibot/login.py

Change-Id: I6569fcb244f2bb19e6e6b34cc769c187a0e1b2eb
---
M login.py
1 file changed, 4 insertions(+), 3 deletions(-)

Approvals:
  DrTrigon: Checked; Looks good to me, but someone else must approve
  Xqt: Looks good to me, approved



diff --git a/login.py b/login.py
index 49befc8..7a812e5 100644
--- a/login.py
+++ b/login.py
@@ -302,7 +302,8 @@
             # As we don't want the password to appear on the screen, we set
             # password = True
             self.password = pywikibot.input(
                                 u'Password for user %(name)s on %(site)s:'
                                 % {'name': self.username, 'site': self.site},
                                 password = True)
 
@@ -372,8 +373,8 @@
     for arg in pywikibot.handleArgs():
         if arg.startswith("-pass"):
             if len(arg) == 5:
-                password = pywikibot.input(u'Password for all accounts:',
-                                           password = True)
+                password = pywikibot.input(u'Password for all accounts ' \
+                    u'(no characters will be shown):', password = True)
             else:
                 password = arg[6:]
         elif arg == "-clean":
@@ -302,7 +302,8 @@
             # password = True
             self.password = pywikibot.input(
-                                u'Password for user %(name)s on %(site)s:'
+                                u'Password for user %(name)s on %(site)s\n' \
+                                u'No characters will be shown:'
                                 % {'name': self.username, 'site': self.site},
                                 password = True)

-- 
To view, visit https://gerrit.wikimedia.org/r/84007
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I6569fcb244f2bb19e6e6b34cc769c187a0e1b2eb
Gerrit-PatchSet: 4
Gerrit-Project: pywikibot/compat
Gerrit-Branch: master
Gerrit-Owner: Ladsgroup <[email protected]>
Gerrit-Reviewer: DrTrigon <[email protected]>
Gerrit-Reviewer: Ladsgroup <[email protected]>
Gerrit-Reviewer: Legoktm <[email protected]>
Gerrit-Reviewer: Xqt <[email protected]>
Gerrit-Reviewer: jenkins-bot

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to